@@ -13,11 +13,7 @@
 
 KDEGrantleePlugin::KDEGrantleePlugin(QObject *parent)
     : QObject(parent)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    , Grantlee::TagLibraryInterface()
-#else
     , KTextTemplate::TagLibraryInterface()
-#endif
 {
     Color::registerMetaType();
     ColorScheme::registerMetaType();
@@ -25,35 +21,19 @@ KDEGrantleePlugin::KDEGrantleePlugin(QObject *parent)
 }
 
 KDEGrantleePlugin::~KDEGrantleePlugin() = default;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-QHash<QString, Grantlee::AbstractNodeFactory *> KDEGrantleePlugin::nodeFactories(const QString &name)
-#else
 QHash<QString, KTextTemplate::AbstractNodeFactory *> KDEGrantleePlugin::nodeFactories(const QString &name)
-#endif
 {
     Q_UNUSED(name)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QHash<QString, Grantlee::AbstractNodeFactory *> nodeFactories;
-#else
     QHash<QString, KTextTemplate::AbstractNodeFactory *> nodeFactories;
-#endif
     nodeFactories[QStringLiteral("colorMix")] = new ColorMixTag();
     nodeFactories[QStringLiteral("icon")] = new IconTag();
 
     return nodeFactories;
 }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-QHash<QString, Grantlee::Filter *> KDEGrantleePlugin::filters(const QString &name)
-#else
 QHash<QString, KTextTemplate::Filter *> KDEGrantleePlugin::filters(const QString &name)
-#endif
 {
     Q_UNUSED(name)
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QHash<QString, Grantlee::Filter *> filters;
-#else
     QHash<QString, KTextTemplate::Filter *> filters;
-#endif
     filters.insert(QStringLiteral("colorHexRgb"), new ColorHexRgbFilter());
     filters.insert(QStringLiteral("colorCssRgba"), new ColorCssRgbaFilter());
     filters.insert(QStringLiteral("colorLighter"), new ColorLighterFilter());
@@ -61,3 +41,5 @@ QHash<QString, KTextTemplate::Filter *> KDEGrantleePlugin::filters(const QString
     filters.insert(QStringLiteral("colorSetAlpha"), new ColorSetAlphaFilter());
     return filters;
 }
+
+#include "moc_kdegrantleeplugin.cpp"
